from setuptools import setup

setup(name='django-coffee',
      version='0.0.4',
      description='Django Coffee',
      url='https://github.com/jacothiart/django-coffee',
      author='Jaco Thiart',
      author_email='jaco@jacothiart.com',
      license='MIT',
      packages=['coffee'],
      zip_safe=False)



class FormMixin(object):
    def construct_widgets(self, fields, placeholders, must_delete=True):
        for field in fields.keys():
            if field in placeholders.keys():
                fields[field].widget.attrs.update({
                    'class': 'form-control',
                    'placeholder': placeholders[field]
                })
            else:
                if must_delete:
                    del fields[field]